@@ -18,12 +18,10 @@
 
 """ADSBXCOT Constants."""
 
-import logging
-import os
-
 __author__ = "Greg Albrecht W2GMD <oss@undef.net>"
 __copyright__ = "Copyright 2022 Greg Albrecht"
 __license__ = "Apache License, Version 2.0"
 
 
 DEFAULT_POLL_INTERVAL: int = 30
+DEFAULT_LIGHT_COT: bool = False
